@@ -33,6 +33,9 @@ View contains three part:
 #include "sequencer_track_view.h"
 #include "startmenu.h"
 
+#include "../jammo-game-task.h"
+#include "../jammo-game-level.h"
+#include "../jammo-game-level-view.h"
 
 /*
 Sequencer and sequencer-track-view-area are defined in json.
@@ -102,6 +105,8 @@ if (load_only_backingtrack){
 
 	jammo_sequencer_set_tempo(static_sequencer,tempo);
 	jammo_sequencer_set_pitch(static_sequencer,pitch);
+	// time signature 4/4 is used for all 7-12 compositions
+	jammo_sequencer_set_time_signature(static_sequencer, 4, 4);
 
 	//Correct GUI-elements:
 	gchar* name_of_tempo_button;
@@ -409,6 +414,10 @@ static void re_parent(ClutterActor* actor, gpointer data) {
 */
 static void re_parent(ClutterContainer* container,ClutterActor* actor) {
 	printf("re parenting\n");
+	if (actor==NULL || clutter_actor_get_parent(actor)==NULL) {
+		printf("canceling: re parenting\n");
+		return;
+	}
 	g_object_ref(actor);
 	clutter_container_remove_actor(CLUTTER_CONTAINER(clutter_actor_get_parent(actor)), actor);
 	clutter_container_add(container,actor,NULL);   //add
@@ -441,6 +450,10 @@ void start_sequencer_full_sequencer (TangleAction *action, GObject *source, cons
 	re_parent(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-track-control-panel")),jammo_get_actor_by_id("track-control-panel-of-this-level"));
 	clutter_actor_show(jammo_get_actor_by_id("track-control-panel-of-this-level"));
 
+	//This is scrore-indicator
+	re_parent(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-container-for-sequencer-view")),jammo_get_actor_by_id("game-level-view"));
+
+
 	//Control-panel has correct height, but track area doesn't.
 	clutter_actor_set_height(jammo_get_actor_by_id("fullsequencer-container-for-tracks"),
          clutter_actor_get_height(jammo_get_actor_by_id("fullsequencer-track-control-panel")));
@@ -468,11 +481,16 @@ void start_sequencer(gpointer filename)
 	}
 
 
+
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 
 
-	//Tune some things that can't be done with JSON only ("clamp-scrolling-offset-y")
-	sequencer_loop_tune_wheels();
+	JammoGameTask* task = jammo_game_level_get_active_task(JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level")));
+	JammoGameTask* task2 = JAMMO_GAME_TASK(jammo_get_object_by_id("level1-task1.json"));
+	if (task==task2)
+		sequencer_loop_tune_wheels(task);
+	else
+		sequencer_loop_tune_wheels(NULL);
 
 	sequencer_track_view_tune_width();
 
@@ -503,6 +521,9 @@ void leave_sequencer()
 
 
 
+
+
+
 /*
  * CallBack for JSON
  */
