@@ -32,14 +32,19 @@ typedef struct {
 	uint e;
 } quad;
 
-static int number_of_cannot_fail_combos = 6; //TODO: calculate dynamically
+static int number_of_cannot_fail_combos = 11; //TODO: calculate dynamically
 static quad cannot_fail_lists[] = {
 	{ 1,0,0,-1    },
 	{ 0,1,1,0     },
 	{ 2,2,2,-1    },
 	{ 3,3,3,-1    },
-	{ 6,-1,-1,1   },
-	{ 7,4,4,-1    }
+	{ 6,8,-1,1    },
+	{ 7,4,4,-1    },
+	{ 3,5,5,2     },
+	{ 5,7,6,-1    },
+	{ 8,8,7,-1    },
+	{ 4,6,9,4     },
+	{ 9,9,8,-1    }
 };
 
 gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
@@ -295,11 +300,14 @@ static samplebutton_tuple rhythms[] = {
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_polka01_$t_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_hiphop07_$t_44_2.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_8beat02_$t_44_1.ogg"}, //Keep index. used for cannot-fail
-	{"wheel_game/darabouka.png","wheel_game/Rh_conga03_$t_44_1.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/darabouka.png","wheel_game/Rh_darabouka03_$t_44_1.ogg"},  //Keep index. used for cannot-fail
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_8beat01_$t_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_rockbeat01_$t_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_dancebeat01_$t_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_disco01_$t_44_1.ogg"},  //Keep index. used for cannot-fail
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon06_$t_44_1.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_elbeat02_$t_44_2.ogg"},  //Keep index. used for cannot-fail
+	{"wheel_game/darabouka.png","wheel_game/Rh_conga03_$t_44_1.ogg"},
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_16beat01_$t_44_1.ogg"},
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_16beat02_$t_44_1.ogg"},
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_8beat03_$t_44_1.ogg"},
@@ -380,6 +388,43 @@ static samplebutton_tuple rhythms[] = {
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_twist01_$t_44_1.ogg"},
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_waltz01_$t_34_1.ogg"},
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_woodblock01_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_BalladTabla_$t_44_2.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_BalladTablaFill_$t_44_2.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon01_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon02_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon03_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon04_$t_44_2.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon07_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon08_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon09_$t_34_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon10_$t_34_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon11_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon12_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_darabouka01_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_darabouka02_$t_34_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_darabouka04_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_darabouka05_$t_34_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe01_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe02_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe03_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe04_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe05_$t_34_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe06_$t_34_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe07_$t_34_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe08_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe09_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe10_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe11_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_FunkyTabla_$t_44_2.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla01_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla02_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla03_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla04_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla05_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla06_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla07_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla08_$t_44_1.ogg"},
+	{"wheel_game/tabla.png","wheel_game/Rh_tabla09_$t_44_1.ogg"},
 	{NULL,NULL}
 };
 
@@ -390,6 +435,12 @@ static samplebutton_tuple melodics[] = {
 	{"wheel_game/cello.png", "wheel_game/Me_cello02_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/flute.png", "wheel_game/Me_flute05_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/organ.png", "wheel_game/Me_organ3_$t_$p_44_2.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass04_$t_$p_44_4.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass20_$t_$p_44_1.ogg"},//Keep index. used for cannot-fail
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass08_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax10_$t_$p_44_1.ogg"},//Keep index. used for cannot-fail
+	{"wheel_game/synthesizer.png", "wheel_game/Me_delaysynth02_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthguitar02_$t_$p_44_2.ogg"},
 	{"wheel_game/clavinet.png", "wheel_game/Me_clavinet01_$t_$p_44_1.ogg"},
 	{"wheel_game/accordion.png", "wheel_game/Me_FolkMetalAccordion1_$t_$p_44_2.ogg"},
 	{"wheel_game/accordion.png", "wheel_game/Me_FolkMetalAccordion2_$t_$p_44_1.ogg"},
@@ -416,7 +467,6 @@ static samplebutton_tuple melodics[] = {
 	{"wheel_game/saxophone.png", "wheel_game/Me_sax07_$t_$p_44_1.ogg"},
 	{"wheel_game/saxophone.png", "wheel_game/Me_sax08_$t_$p_44_2.ogg"},
 	{"wheel_game/saxophone.png", "wheel_game/Me_sax09_$t_$p_44_2.ogg"},
-	{"wheel_game/saxophone.png", "wheel_game/Me_sax10_$t_$p_44_1.ogg"},
 	{"wheel_game/saxophone.png", "wheel_game/Me_sax11_$t_$p_44_2.ogg"},
 	{"wheel_game/saxophone.png", "wheel_game/Me_sax12_$t_$p_44_2.ogg"},
 	{"wheel_game/saxophone.png", "wheel_game/Me_ScarboroughFairSax_$t_$p_44_8.ogg"},
@@ -467,6 +517,89 @@ static samplebutton_tuple melodics[] = {
 	{"wheel_game/flute.png", "wheel_game/Me_flute12_$t_$p_44_2.ogg"},
 	{"wheel_game/flute.png", "wheel_game/Me_flute13_$t_$p_44_2.ogg"},
 	{"wheel_game/flute.png", "wheel_game/Me_flute14_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass01_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass02_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass03_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass05_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass06_$t_$p_44_4.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass07_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass09_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass10_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass11_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass12_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass13_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass14_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass15_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass16_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass17_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass18_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass19_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass21_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass22_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass23_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass24_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_ebass25_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_FolkMetalBass1_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_FolkMetalBass2_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HiLifeBass1_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HiLifeBass2_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HiLifeBass3_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HiLifeBass4_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_LatinBass1_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_Latinbass2_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_LatinBass3_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_eguitar05_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_eguitar06_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_HiLifeGuitar1_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_HiLifeGuitar2_$t_$p_44_1.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_HiLifeGuitar3_$t_$p_44_1.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_HiLifeGuitar4_$t_$p_44_1.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_LatinGuitar1_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Me_LatinGuitar2_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_GrimeSynthBass1_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_GrimeSynthBass2_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HipHopBalladBassLine1_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HipHopBalladBassLine2_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HipHopBalladBassLine3_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_HipHopBalladBassLine4_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_SocaBassLine1_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_SocaBassLine2_$t_$p_44_2.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_SocaBassLine3_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_delaysynth01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_hiphopbass01_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_hiphopbass02_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_hiphopbass03_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_hiphopbass04_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_hiphopbass05_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbass01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbass02_$t_$p_44_4.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbass03_$t_$p_44_4.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbell01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbell02_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbell03_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbrass_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthguitar01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthguitar03_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthlead01_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthlead02_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthriff_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_SynthScale_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin01_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin02_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin03_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin04_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin05_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin06_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin07_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin08_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin09_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin10_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin14_$t_$p_34_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin15_$t_$p_34_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin16_$t_$p_34_2.ogg"},
+	{"wheel_game/cello.png", "wheel_game/Me_cello06_$t_$p_44_2.ogg"},
+	{"wheel_game/cello.png", "wheel_game/Me_cello07_$t_$p_44_2.ogg"},
+	{"wheel_game/cello.png", "wheel_game/Me_cello08_$t_$p_44_1.ogg"},
 	{NULL,NULL}
 };
 
@@ -476,12 +609,16 @@ static samplebutton_tuple harmonics[] = {
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar01_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/strings.png", "wheel_game/Ha_strings04_$t_$p_44_2.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/organ.png", "wheel_game/Ha_organ01_$t_$p_44_2.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/piano.png", "wheel_game/Ha_piano04_$t_$p_44_4.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/cello.png", "wheel_game/Ha_cello03_$t_$p_44_1.ogg"},  //Keep index. used for cannot-fail
+	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar11_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/piano.png", "wheel_game/Ha_piano15_$t_$p_44_2.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar03_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/electric_piano.png", "wheel_game/Ha_HiLifeElecPiano_$t_$p_44_2.ogg"},
 	{"wheel_game/accordion.png", "wheel_game/Ha_accordion02_$t_$p_44_1.ogg"},
 	{"wheel_game/accordion.png", "wheel_game/Ha_SocaAccordionRiff1_$t_$p_44_2.ogg"},
 	{"wheel_game/accordion.png", "wheel_game/Ha_SocaAccordionRiff2_$t_$p_44_2.ogg"},
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar02_$t_$p_44_1.ogg"},
-	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar02_$t_$p_44_1.ogg"},
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar04_$t_$p_44_2.ogg"},
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar05_$t_$p_44_2.ogg"},
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar08_$t_$p_34_2.ogg"},
@@ -507,7 +644,6 @@ static samplebutton_tuple harmonics[] = {
 	{"wheel_game/piano.png", "wheel_game/Ha_MontunoPiano2_$t_$p_44_1.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano02_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano03_$t_$p_44_2.ogg"},
-	{"wheel_game/piano.png", "wheel_game/Ha_piano04_$t_$p_44_4.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano05_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano06_$t_$p_44_4.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano07_$t_$p_44.ogg"},
@@ -517,19 +653,48 @@ static samplebutton_tuple harmonics[] = {
 	{"wheel_game/piano.png", "wheel_game/Ha_piano11_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano12_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano14_$t_$p_44_4.ogg"},
-	{"wheel_game/piano.png", "wheel_game/Ha_piano15_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano16_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_piano17_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_SocaPianoRiff1_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_SocaPianoRiff2_$t_$p_44_2.ogg"},
 	{"wheel_game/piano.png", "wheel_game/Ha_SocaPianoRiff3_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_eguitar01_$t_$p_44_1.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_eguitar02_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_eguitar03_$t_$p_44_4.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_eguitar04_$t_$p_44_4.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_eguitar07_$t_$p_44_1.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_eguitar08_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_FolkMetalPickedGuitar1_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_FolkMetalPickedGuitar2_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Ha_FolkMetalThrashGuitar1_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_GrimeSynth1_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_GrimeSynth2_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_synth01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_synth02_$t_$p_44_4.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_synthbrass_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_synthstrings01_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_synthstrings02_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_WashChords1_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Ha_WashChords2_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Ha_violin11_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Ha_violin12_$t_$p_44_1.ogg"},
+	{"wheel_game/violin.png","wheel_game/Ha_violin13_$t_$p_34_2.ogg"},
+	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar06_$t_$p_44_2.ogg"},
+	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar07_$t_$p_44_2.ogg"},
+	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar09_$t_$p_34_2.ogg"},
+	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar10_$t_$p_34_2.ogg"},
 	{NULL,NULL}
 };
 
 
+
+
+
 static samplebutton_tuple effects[] = {
 	{"wheel_game/tambourine.png", "wheel_game/Fx_tambourine04_$t_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/soundscape.png", "wheel_game/Fx_swoosh_$t_44_2.ogg"}, //Keep index. used for cannot-fail
+	{"wheel_game/fx.png", "wheel_game/Fx_scratch_$t_44_1.ogg"}, //Keep index. used for cannot-fail //TODO:icon
+	{"wheel_game/synthpad.png", "wheel_game/Fx_pulsesynth_$t_$p_44_1.ogg"}, //Keep index. used for cannot-fail
 	{"wheel_game/fx.png", "wheel_game/Fx_robot_$t_$p_$p_44_2.ogg"}, //TODO:icon
 	{"wheel_game/electric_piano.png", "wheel_game/Fx_synth01_$t_44_1.ogg"},
 	{"wheel_game/electric_piano.png", "wheel_game/Fx_synth02_$t_44_1.ogg"},
@@ -541,23 +706,39 @@ static samplebutton_tuple effects[] = {
 	{"wheel_game/fx.png", "wheel_game/Fx_chimes_$t_34_4.ogg"}, //TODO:icon
 	{"wheel_game/fx.png", "wheel_game/Fx_glidesynth_$t_$p_44_4.ogg"}, //TODO:icon
 	{"wheel_game/fx.png", "wheel_game/Fx_rubber_$t_44_1.ogg"}, //TODO:icon
-	{"wheel_game/fx.png", "wheel_game/Fx_scratch_$t_44_1.ogg"}, //TODO:icon
 	{"wheel_game/strings.png", "wheel_game/Fx_BollywoodStrings_$t_$p_44_2.ogg"},
 	{"wheel_game/strings.png", "wheel_game/Fx_StringStabs_$t_$p_44_2.ogg"},
+	{"wheel_game/electric_guitar.png", "wheel_game/Fx_FolkMetalThrashHarmonics_$t_$p_44_2.ogg"},
+	{"wheel_game/darabouka.png", "wheel_game/Fx_Sarangi_$t_$p_44_1.ogg"},
+	{"wheel_game/tambourine.png", "wheel_game/Fx_TampuraDrone_$t_$p_44_2.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Fx_SquelchySynth_$t_$p_44_2.ogg"},
+	{"wheel_game/banana_vocal.png", "wheel_game/Fx_DayDahLightVocal1_$t_$p_44_2.ogg"},
+	{"wheel_game/banana_vocal.png", "wheel_game/Fx_DayDahLightVocal2_$t_$p_44_2.ogg"},
+	{"wheel_game/banana_vocal.png", "wheel_game/Fx_DayDahLightVocal3_$t_$p_44_2.ogg"},
+	{"wheel_game/labamba_vocal.png", "wheel_game/Fx_LaBambaVocal1_$t_$p_44_4.ogg"},
+	{"wheel_game/labamba_vocal.png", "wheel_game/Fx_LaBambaVocal2_$t_$p_44_2.ogg"},
+	{"wheel_game/hamba_vocal.png", "wheel_game/Fx_SiyaHambaVocal1_$t_$p_44_4.ogg"},
+	{"wheel_game/hamba_vocal.png", "wheel_game/Fx_SiyaHambaVocal2_$t_$p_44_4.ogg"},
+	{"wheel_game/hamba_vocal.png", "wheel_game/Fx_SiyaHambaVocal3_$t_$p_44_4.ogg"},
+	{"wheel_game/synthpad.png", "wheel_game/Fx_filterpulse_$t_$p_44_2.ogg"},
+	{"wheel_game/synthpad.png", "wheel_game/Fx_synthpulse_$t_$p_44_1.ogg"},
 	{NULL,NULL}
 };
 
 
+
+
+#include "level1.h"
 /*
 loop_type:
-100=rhythms
-200=melodics
-300=harmonics
-400=effects
+1000=rhythms
+2000=melodics
+3000=harmonics
+4000=effects
 
 returns number of this type of sample_buttons
 */
-static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[], int loop_type) {
+static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[], int loop_type, JammoGameTask* task) {
 	samplebutton_tuple new_button=table[0];
 	int counter=0;
 	while(new_button.image){
@@ -567,12 +748,22 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
 		sample_button = jammo_sample_button_new(); //TODO: jammo_sample_button_new_with_type
 		g_object_set(sample_button,"sequencer", jammo_get_object_by_id("fullsequencer-the-sequencer"),NULL);
+		//printf("DEBUG: looking image: '%s' and audio: '%s'\n",full_image,full_sound);
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
 
+		int loop_id = counter+loop_type;
+
+		if (task){
+			gchar* act_name = g_strdup_printf("%d",counter+loop_type);
+			jammo_game_task_add_act(task, act_name);
+			g_signal_connect(sample_button,"listened", G_CALLBACK(level1_sample_button_on_wheel_listened),task);
+			g_free(act_name);
+		}
+
 		g_object_set(sample_button,"drag-threshold-y",10000,NULL); //No dragging by vertical-axis (it is for scrolling wheel)
 
-		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), counter+loop_type);
+		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), loop_id);
 		g_free(full_image);
 		g_free(full_sound);
 
@@ -585,17 +776,17 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 
 
 
-void sequencer_loop_tune_wheels() {
+void sequencer_loop_tune_wheels(JammoGameTask* task) {
 	//Static
 	rhytmical_sample_looper  =  jammo_get_actor_by_id("fullsequencer-loop-rhytmical-wheel-scroller");
 	melodical_sample_looper  =  jammo_get_actor_by_id("fullsequencer-loop-melodical-wheel-scroller");
 	harmonical_sample_looper =  jammo_get_actor_by_id("fullsequencer-loop-harmonical-wheel-scroller");
 	effect_sample_looper     =  jammo_get_actor_by_id("fullsequencer-loop-effect-wheel-scroller");
 
-	length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,100);
-	length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,200);
-	length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,300);
-	length_of_effects = add_sample_buttons(effect_sample_looper,effects,400);
+	length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,1000,task);
+	length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,2000,task);
+	length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,3000,task);
+	length_of_effects = add_sample_buttons(effect_sample_looper,effects,4000,task);
 
 	fine_tune_wheel(rhytmical_sample_looper);
 	fine_tune_wheel(melodical_sample_looper);
@@ -617,22 +808,22 @@ ClutterActor* sequencer_loop_give_sample_button_for_this_id(guint id){
 	int length_of_asked;
 	guint id_; //Id without first digit
 	//gchar* type;  //TODO: use this
-	if (id>=100 && id <200){
+	if (id>=1000 && id <2000){
 		asked_table=rhythms;
 		length_of_asked=length_of_rhythms;
-		id_=id-100;
-	} else if (id>=200 && id <300) {
+		id_=id-1000;
+	} else if (id>=2000 && id <3000) {
 		asked_table=melodics;
 		length_of_asked=length_of_melodics;
-		id_=id-200;
-	} else if (id>=300 && id <400) {
+		id_=id-2000;
+	} else if (id>=3000 && id <4000) {
 		asked_table=harmonics;
 		length_of_asked=length_of_harmonics;
-		id_=id-300;
-	}	else if (id>=400 && id <500) {
+		id_=id-3000;
+	}	else if (id>=4000 && id <5000) {
 		asked_table=effects;
 		length_of_asked=length_of_effects;
-		id_=id-400;
+		id_=id-4000;
 	} else {
 		return NULL;
 	}
