@@ -8,20 +8,19 @@ This is the sequencer.
 #include <glib-object.h>
 #include "startmenu.h"
 #include "../jammo.h"
+#include "../jammo-game-level.h"
 #include "sequencer.h"
 #include "gamesmenu.h"
 #include "communitymenu.h"
 
 #include "../../cem/cem.h"
 
-//Used when coming back to startmenu (unload)
-static ClutterActor* last_used_level = NULL;
-
 void startmenu_goto_sequencer (TangleButton* tanglebutton, gpointer none){
 	printf("startmenu_goto_sequencer\n");
 
-	last_used_level = jammo_get_actor_by_id("level1-view");
-	clutter_actor_show(jammo_get_actor_by_id("level1-view")); //TODO: level1000-view (last-level)
+	//We want find "game-level" and it is defined on "levelX-view"
+	tangle_view_load_now(TANGLE_VIEW(jammo_get_actor_by_id("level1-view")));
+	jammo_game_level_start_task(JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level")),"level1-task1.json");  //TODO: level1000-view (last-level)
 	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
 
 	clutter_actor_hide(jammo_get_actor_by_id("startmenu-view"));
@@ -90,12 +89,6 @@ void startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("startmenu_goto_startmenu-called",LOG_USER_ACTION);
 	tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("fullsequencer-view")));
 
-	//TODO!
-	if (last_used_level)
-		tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("level1-view")));
-	else
-		tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("level2-view")));
-
 	ClutterActor* mainview;
 	mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
