@@ -35,6 +35,10 @@
 #include "7-12gui/communitymenu.h"
 #include "7-12gui/gamesmenu.h"
 
+#include "jammo-game-task.h"
+#include "jammo-game-level.h"
+#include "jammo-game-level-view.h"
+
 #include "../gems/gems.h"
 //#include "singinggame.h"
 
@@ -273,6 +277,8 @@ int main(int argc, char** argv) {
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
 	printf("%ld %ld %ld\n", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION, (long)JAMMO_TYPE_TRACK_VIEW);
+	/* Orientation games related */
+	printf("%ld %ld %ld\n",  (long)JAMMO_TYPE_GAME_TASK,  (long)JAMMO_TYPE_GAME_LEVEL,  (long)JAMMO_TYPE_GAME_LEVEL_VIEW);
 
 	if ((stylesheet = get_jammo_stylesheet())) {
 		tangle_stylesheet_set_default(stylesheet);
@@ -336,7 +342,11 @@ int main(int argc, char** argv) {
 	printf("LANG='%s'\n",lang);
 
 	gchar* lang2=g_strndup (lang,5); //omit charset.
-	gchar* path = g_strdup_printf("mentor_speech/%s",lang2);
+	gchar* path;
+	if (!strcmp(application_name,"jammo7_12"))
+		path = g_strdup_printf("mentor_speech7_12/%s",lang2);
+	else
+		path = g_strdup_printf("mentor_speech/%s",lang2);
 
 	printf("language path='%s'\n",path);
 	jammo_mentor_set_language(jammo_mentor_get_default(),path);
