@@ -12,7 +12,7 @@
 #define PG_PASSWORD_TEXT_FILE JAMMO_DIRECTORY "/pg-passwords"
 #define PG_IMAGES_DIR DATA_DIR "/password";
 #define INKML_FILE_PATH JAMMO_DIRECTORY "/motion_inkml.xml";
-#define PG_VERSION "v.0.7.0";
+#define PG_VERSION "v.0.7.1";
 
 //FULL SCREEN  MESSAGES 300x200 QUE FONTita! 32px
 #define PG_PASSWORD_ERROR "wrong_password.png"
@@ -22,6 +22,10 @@
 //SMALL MESSAGES 200x100 QUE FONTita! 32px
 #define PG_RESET_PASSWD_MESSAGE "reset_passwd_msg.png"
 
+
+//TEMPORARY 4 TESTING
+#define MYJAMMERSOUNDPATH DATA_DIR "/jammer/jammersounds/mari/mari_a3.ogg"
+
 #endif /* CONFIG_H_ */
 
 
