@@ -44,6 +44,19 @@ JammoBackingTrack* jammo_backing_track_new(const gchar* filename) {
 	return JAMMO_BACKING_TRACK(g_object_new(JAMMO_TYPE_BACKING_TRACK, "filename", filename, NULL));
 }
 
+const gchar* jammo_backing_track_get_filename(JammoBackingTrack* backing_track) {
+
+	return backing_track->priv->filename;
+}
+
+void jammo_backing_track_set_filename(JammoBackingTrack* backing_track, const gchar* filename) {
+	if (g_strcmp0(backing_track->priv->filename, filename)) {
+		g_free(backing_track->priv->filename);
+		backing_track->priv->filename = g_strdup(filename);
+		setup_source(backing_track);
+		g_object_notify(G_OBJECT(backing_track), "filename");
+	}
+}
 
 static void jammo_backing_track_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoBackingTrack* backing_track;
@@ -52,8 +65,7 @@ static void jammo_backing_track_set_property(GObject* object, guint prop_id, con
 
 	switch (prop_id) {
 		case PROP_FILENAME:
-			g_assert(!backing_track->priv->filename);
-			backing_track->priv->filename = g_strdup(g_value_get_string(value));
+			jammo_backing_track_set_filename(backing_track, g_value_get_string(value));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -84,8 +96,9 @@ static guint64 jammo_backing_track_get_duration(JammoTrack* track) {
 	
 	backing_track = JAMMO_BACKING_TRACK(track);
 	
-	if (backing_track->priv->duration == JAMMO_DURATION_INVALID &&
-	   ((backing_track->priv->duration = jammo_meam_get_cached_duration(backing_track->priv->real_filename)) == JAMMO_DURATION_INVALID)) {
+	if (backing_track->priv->real_filename &&
+	    backing_track->priv->duration == JAMMO_DURATION_INVALID &&
+	    ((backing_track->priv->duration = jammo_meam_get_cached_duration(backing_track->priv->real_filename)) == JAMMO_DURATION_INVALID)) {
 		g_message("No cached duration for '%s', prerolling.", backing_track->priv->real_filename);
 
 		preroll(backing_track);
@@ -178,7 +191,7 @@ static void jammo_backing_track_class_init(JammoBackingTrackClass* backing_track
 	                                "File name",
 	                                "The file name of the played audio",
 	                                NULL,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * JammoBackingTrack:real-filename:
 	 */
@@ -294,6 +307,7 @@ static gchar* str_replace(gchar* string, gsize position, gsize length, const gch
 }
 
 static void setup_source(JammoBackingTrack* backing_track) {
+	gboolean parameters_ok = TRUE;
 	gchar* filename;
 	gchar* s;
 	gchar* tempo_string;
@@ -301,7 +315,7 @@ static void setup_source(JammoBackingTrack* backing_track) {
 	
 	if (backing_track->priv->source) {
 		filename = s = g_strdup(backing_track->priv->filename);
-		while ((s = strchr(s, '$'))) {
+		while (parameters_ok &&(s = strchr(s, '$'))) {
 			switch (s[1]) {
 				case '$':
 					filename = str_replace(filename, s - filename, 2, "$", &s);
@@ -312,7 +326,11 @@ static void setup_source(JammoBackingTrack* backing_track) {
 					g_free(tempo_string);
 					break;
 				case 'p':
-					filename = str_replace(filename, s - filename, 2, (backing_track->priv->pitch ? backing_track->priv->pitch : "?"), &s);
+					if (backing_track->priv->pitch) {
+						filename = str_replace(filename, s - filename, 2, backing_track->priv->pitch, &s);
+					} else {
+						parameters_ok = FALSE;
+					}
 					break;
 				default:
 					g_warning("Unexpected parameter in the backing track filename: '$%c', skipped.", s[1]);
@@ -321,7 +339,7 @@ static void setup_source(JammoBackingTrack* backing_track) {
 			}
 		}
 
-		if (g_strcmp0(backing_track->priv->real_filename, filename)) {
+		if (parameters_ok && g_strcmp0(backing_track->priv->real_filename, filename)) {
 			g_free(backing_track->priv->real_filename);
 			backing_track->priv->real_filename = filename;
 
