@@ -22,9 +22,6 @@
 // value does not matter but there has to be a reference tempo
 #define DEFAULT_TEMPO 110.0
 
-// desired latency for instrument track in us
-#define INSTRUMENT_TRACK_LATENCY 10000
-
 G_DEFINE_TYPE(JammoInstrumentTrack, jammo_instrument_track, JAMMO_TYPE_PLAYING_TRACK);
 
 enum {
@@ -70,10 +67,6 @@ static void jammo_instrument_track_set_offline(JammoTrack* track, gboolean offli
 	jammo_instrument_track_set_realtime(instrument_track, !offline);
 }
 
-static gint64 jammo_instrument_track_latency_query(JammoTrack* track) {
-		return INSTRUMENT_TRACK_LATENCY;
-}
-
 static void jammo_instrument_track_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoInstrumentTrack* instrument_track;
 	
@@ -229,8 +222,9 @@ static void jammo_instrument_track_class_init(JammoInstrumentTrackClass* instrum
 	track_class->set_offline = jammo_instrument_track_set_offline;
 	track_class->set_pitch = jammo_instrument_track_set_pitch;
 	track_class->set_tempo = jammo_instrument_track_set_tempo;
-	track_class->latency_query = jammo_instrument_track_latency_query;
+
 	playing_track_class->setup_playing_element = jammo_instrument_track_setup_playing_element;
+
 	gobject_class->finalize = jammo_instrument_track_finalize;
 	gobject_class->dispose = jammo_instrument_track_dispose;
 	gobject_class->set_property = jammo_instrument_track_set_property;
@@ -343,6 +337,10 @@ GList * jammo_instrument_track_get_event_list(JammoInstrumentTrack* instrument_t
 }
 
 void jammo_instrument_track_set_event_list(JammoInstrumentTrack* instrument_track, GList* eventlist) {
+	if (instrument_track->priv->element==NULL) {
+		printf("Can't add eventlist to instrument-track, maybe track is not attached to sequencer (it must be before adding events)\n");
+		return;
+	}
 	g_object_set(G_OBJECT(instrument_track->priv->element),"eventlist", eventlist, NULL);
 }
 
@@ -366,21 +364,6 @@ void jammo_instrument_track_load_to_track_from_file (JammoInstrumentTrack* instr
         jammo_instrument_track_set_event_list(instrument_track, list);
 }
 
-
-/**
-	Creates new instrument_track containing midi events from given filename.
-	FIXME: some reason this function is not working correctly. Even events is added to track, they are not in track!
-
-	type: 0= flute, 1=drumkit ,2=ud
- * @param filename
- */
-JammoInstrumentTrack* jammo_instrument_track_new_from_file(gchar *filename, int type) {
-	JammoInstrumentTrack* instrument_track;
-	instrument_track = jammo_instrument_track_new(type);
-	jammo_instrument_track_load_to_track_from_file(instrument_track,filename);
-	return instrument_track;
-}
-
 /**
 	Clears event list of sampler. All recorded and added events are lost.
 **/
