@@ -103,7 +103,7 @@ static gboolean jammo_recording_track_receive_message(JammoTrack* track, GstMess
 	return retvalue;
 }
 
-static gboolean jammo_recording_track_setup_element(JammoTrack* track, GstBin* bin, GstElement* sink_element) {
+static gboolean jammo_recording_track_setup_element(JammoTrack* track, GstPipeline* pipeline, GstBin* bin, GstElement* sink_element) {
 	JammoRecordingTrack* recording_track;
 	GstElement* source;
 	GstElement* convert;
@@ -113,7 +113,7 @@ static gboolean jammo_recording_track_setup_element(JammoTrack* track, GstBin* b
 	GstElement* sink;
 
 	recording_track = JAMMO_RECORDING_TRACK(track);
-	source = gst_element_factory_make("autoaudiosrc", NULL);
+	source = gst_element_factory_make("pulsesrc", NULL);
 	convert = gst_element_factory_make("audioconvert", NULL);
 	if (recording_track->priv->pitch_detect) {
 		if (!(pitch = gst_element_factory_make("pitchdetect", NULL))) {
@@ -128,10 +128,10 @@ static gboolean jammo_recording_track_setup_element(JammoTrack* track, GstBin* b
 	g_assert(recording_track->priv->filename);
 	g_object_set(sink, "location", recording_track->priv->filename, NULL);
 	if (recording_track->priv->pitch_detect) {
-		gst_bin_add_many(bin, source, convert, pitch, pitch_convert, encoder, sink, NULL);
+		gst_bin_add_many(GST_BIN(pipeline), source, convert, pitch, pitch_convert, encoder, sink, NULL);
 		gst_element_link_many(source, convert, pitch, pitch_convert, encoder, sink, NULL);
 	} else {
-		gst_bin_add_many(bin, source, convert, encoder, sink, NULL);
+		gst_bin_add_many(GST_BIN(pipeline), source, convert, encoder, sink, NULL);
 		gst_element_link_many(source, convert, encoder, sink, NULL);
 	}
 	
