@@ -691,7 +691,8 @@ static void initialize_state(JammoSample* sample) {
 				     "location", sample->priv->real_filename,
 				     "media-start", 0 * GST_SECOND,
 					     NULL);
-			if (sample->priv->duration != JAMMO_DURATION_INVALID) {
+			if (sample->priv->duration != JAMMO_DURATION_INVALID ||
+			    (sample->priv->duration = jammo_meam_get_cached_duration(sample->priv->real_filename)) != JAMMO_DURATION_INVALID) {
 				g_object_set(sample->priv->element,
 		        		     "duration", sample->priv->duration,
 					     "media-duration", sample->priv->duration,
